==> paraview-v3.0.2.zip: paraview-v3.0.2/Qt/Core/pqProxyUnRegisterUndoElement.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqProxyUnRegisterUndoElement.cxx

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.1. 

   See License_v1.1.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqProxyUnRegisterUndoElement.h"

#include "vtkObjectFactory.h"
#include "vtkPVXMLElement.h"
#include "vtkSMProxy.h"

#include "pqApplicationCore.h"
#include "pqProxy.h"
#include "pqServerManagerModel.h"

vtkStandardNewMacro(pqProxyUnRegisterUndoElement);
vtkCxxRevisionMacro(pqProxyUnRegisterUndoElement, "1.1");
//-----------------------------------------------------------------------------
pqProxyUnRegisterUndoElement::pqProxyUnRegisterUndoElement()
{
}

//-----------------------------------------------------------------------------
pqProxyUnRegisterUndoElement::~pqProxyUnRegisterUndoElement()
{
}

//-----------------------------------------------------------------------------
bool pqProxyUnRegisterUndoElement::CanLoadState(vtkPVXMLElement* elem)
{
  return (elem && elem->GetName() && 
    strcmp(elem->GetName(), "PQProxyUnRegister") == 0);
}

//-----------------------------------------------------------------------------
void pqProxyUnRegisterUndoElement::ProxyToUnRegister(
  const char* groupname, const char* proxyname, vtkSMProxy* proxy)
{
  this->Superclass::ProxyToUnRegister(groupname, proxyname, proxy);

  pqApplicationCore* core = pqApplicationCore::instance();
  pqServerManagerModel* smmodel = core->getServerManagerModel();

  pqProxy* pq_proxy = smmodel->getPQProxy(proxy);
  if (!pq_proxy || !this->XMLElement)
    {
    // nothing extra to add.
    return;
    }

  // change the element name so that this object will be created correctly
  // when loading.
  this->XMLElement->SetName("PQProxyUnRegister");

  vtkPVXMLElement* element = vtkPVXMLElement::New();
  element->SetName("HelperProxies");

  QList<QString> keys = pq_proxy->getHelperKeys();
  for (int cc=0; cc < keys.size(); cc++)
    {
    QString key = keys[cc];
    QList<vtkSMProxy*> helpers = pq_proxy->getHelperProxies(key);
    foreach (vtkSMProxy* helper, helpers)
      {
      vtkPVXMLElement* child = vtkPVXMLElement::New();
      child->SetName("Item");
      child->AddAttribute("id", helper->GetSelfIDAsString());
      child->AddAttribute("name", key.toAscii().data());
      element->AddNestedElement(child);
      child->Delete();
      }
    }

  this->XMLElement->AddNestedElement(element);
  element->Delete();
}

//-----------------------------------------------------------------------------
int pqProxyUnRegisterUndoElement::Undo()
{
  if (!this->Superclass::Undo())
    {
    return 0;
    }

  return 1;  
}

//-----------------------------------------------------------------------------
void pqProxyUnRegisterUndoElement::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

==> paraview-v3.2.1.zip: paraview-v3.2.1/Qt/Core/pqProxyUnRegisterUndoElement.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqProxyUnRegisterUndoElement.cxx

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.1. 

   See License_v1.1.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqProxyUnRegisterUndoElement.h"

#include "vtkObjectFactory.h"
#include "vtkPVXMLElement.h"
#include "vtkSMProxy.h"

#include "pqApplicationCore.h"
#include "pqProxy.h"
#include "pqServerManagerModel.h"

vtkStandardNewMacro(pqProxyUnRegisterUndoElement);
vtkCxxRevisionMacro(pqProxyUnRegisterUndoElement, "1.2");
//-----------------------------------------------------------------------------
pqProxyUnRegisterUndoElement::pqProxyUnRegisterUndoElement()
{
}

//-----------------------------------------------------------------------------
pqProxyUnRegisterUndoElement::~pqProxyUnRegisterUndoElement()
{
}

//-----------------------------------------------------------------------------
bool pqProxyUnRegisterUndoElement::CanLoadState(vtkPVXMLElement* elem)
{
  return (elem && elem->GetName() && 
    strcmp(elem->GetName(), "PQProxyUnRegister") == 0);
}

//-----------------------------------------------------------------------------
void pqProxyUnRegisterUndoElement::ProxyToUnRegister(
  const char* groupname, const char* proxyname, vtkSMProxy* proxy)
{
  this->Superclass::ProxyToUnRegister(groupname, proxyname, proxy);

  pqApplicationCore* core = pqApplicationCore::instance();
  pqServerManagerModel* smmodel = core->getServerManagerModel();

  pqProxy* pq_proxy = smmodel->findItem<pqProxy*>(proxy);
  if (!pq_proxy || !this->XMLElement)
    {
    // nothing extra to add.
    return;
    }

  // change the element name so that this object will be created correctly
  // when loading.
  this->XMLElement->SetName("PQProxyUnRegister");

  vtkPVXMLElement* element = vtkPVXMLElement::New();
  element->SetName("HelperProxies");

  QList<QString> keys = pq_proxy->getHelperKeys();
  for (int cc=0; cc < keys.size(); cc++)
    {
    QString key = keys[cc];
    QList<vtkSMProxy*> helpers = pq_proxy->getHelperProxies(key);
    foreach (vtkSMProxy* helper, helpers)
      {
      vtkPVXMLElement* child = vtkPVXMLElement::New();
      child->SetName("Item");
      child->AddAttribute("id", helper->GetSelfIDAsString());
      child->AddAttribute("name", key.toAscii().data());
      element->AddNestedElement(child);
      child->Delete();
      }
    }

  this->XMLElement->AddNestedElement(element);
  element->Delete();
}

//-----------------------------------------------------------------------------
int pqProxyUnRegisterUndoElement::Undo()
{
  if (!this->Superclass::Undo())
    {
    return 0;
    }

  return 1;  
}

//-----------------------------------------------------------------------------
void pqProxyUnRegisterUndoElement::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}
